@@ -36,7 +36,7 @@ UCHARS_v460 = {
 
 
 six.moves.reload_module(sys)
-if (sys.version_info < (3, 0)):
+if six.PY2:
     sys.setdefaultencoding('utf8')
 
 if os.name == 'nt':
@@ -206,7 +206,7 @@ def _clean_str(value):
     ret = value + "/*" + hex(random.randint(0,99999999)) + "*/"
     for c, u in UCHARS.items():
         ret = ret.replace(c, u)
-    return ret
+    return SHADESC + ret
 
 
 def _gen_list_func(gen_mdtype=None):
@@ -216,7 +216,7 @@ def _gen_list_func(gen_mdtype=None):
     def_kwargs.update(_global_args)
     def list_template(unbound=False, gen_mdtype=gen_mdtype, def_kwargs=def_kwargs, **kwargs):
         _do_update_kwargs(def_kwargs, kwargs)
-        ret = SHADESC + _build_eval(**kwargs) + " list_" + gen_mdtype + 's' + _build_inheritance(**kwargs)
+        ret = _build_eval(**kwargs) + " list_" + gen_mdtype + 's' + _build_inheritance(**kwargs)
         if unbound:
             ret += '_unbound'
         return _clean_str(ret)
@@ -248,7 +248,7 @@ def _gen_read_func(gen_mdtype=None, gen_read_type=None):
         # XXX DFQ objective values should always be unbound, on setting? getting? both?
 
         _do_update_kwargs(def_kwargs, kwargs)
-        ret = SHADESC + _build_eval(**kwargs) + " " + gen_read_type + "_" + gen_mdtype + _build_inheritance(**kwargs)
+        ret = _build_eval(**kwargs) + " " + gen_read_type + "_" + gen_mdtype + _build_inheritance(**kwargs)
         if gen_read_type == 'get' and unbound:
             ret += '_unbound'
         ret += '('
@@ -284,7 +284,7 @@ def _gen_update_func(gen_mdtype=None, gen_update_type=None, gen_table=None):
         # XXX DFQ objective values should always be unbound, on setting? getting? both?
         # XXX DFA Both
 
-        ret = SHADESC + _build_set(**kwargs)
+        ret = _build_set(**kwargs)
 
         if gen_mdtype == 'attribute':
             # annoying special case
@@ -327,7 +327,7 @@ def _gen_del_func(gen_mdtype=None, gen_table=None):
 
         # XXX DFQ objective values should always be unbound, on setting? getting? both?
         # XXX DFA - on both
-        ret = SHADESC + _build_set(**kwargs) + ' '
+        ret = _build_set(**kwargs) + ' '
 
         if gen_mdtype == 'attribute':
             # annoying special case
@@ -393,7 +393,7 @@ def eval(value=None, **kwargs):
 
     if not isinstance(value, HSExp):
         raise RuntimeError('value must be of type HSExp, passed in type ' + str(type(value)))
-    ret = SHADESC + _build_eval(**kwargs)
+    ret = _build_eval(**kwargs)
     if value.input_json is True:
         ret += " EVAL(EXPRESSION_FROM_JSON('" + str(value) + "'))"
     else:
@@ -408,7 +408,7 @@ def sum(value=None, **kwargs):
 
     if not isinstance(value, HSExp):
         raise RuntimeError('value must be of type HSExp, passed in type ' + str(type(value)))
-    ret = SHADESC + _build_sum(**kwargs);
+    ret = _build_sum(**kwargs);
     if value.input_json is True:
         ret += " EVAL(EXPRESSION_FROM_JSON('" + str(value) + "'))"
     else:
@@ -421,14 +421,14 @@ def sum(value=None, **kwargs):
 ###
 
 def rm_rf(value=None, **kwargs):
-    return _clean_str(SHADESC + "rm-rf")
+    return _clean_str("rm-rf")
 
 def cp_a(value=None, **kwargs):
-    ret = SHADESC + "cp-a %d" % (kwargs['dest_inode'])
+    ret = "cp-a %d" % (kwargs['dest_inode'])
     return _clean_str(ret)
 
 def inode_info(value=None, **kwargs):
-    ret = SHADESC + "attribute=inode_info"
+    ret = "attribute=inode_info"
     return _clean_str(ret)
 
 if __name__ == '__main__':
